@@ -21,7 +21,7 @@ from h2.events import (
 
 class HttpStruct:
     _stream_id: int
-    _headers: list[tuple[bytes, bytes]] = None
+    _headers: list = None
     _data: bytes = b''
 
     def __init__(self, stream_id: int):
@@ -131,7 +131,7 @@ def negotiate_tls(tcp_conn, context, host, http2_prior_knowledge=False):
     return tls_conn
 
 
-def url_analyze(url) -> tuple[str, str, int, str]:
+def url_analyze(url) -> tuple:
     u = parse_url(url.strip())
     host = u.host
     port = u.port if u.port is not None else 443
@@ -139,7 +139,7 @@ def url_analyze(url) -> tuple[str, str, int, str]:
     return u.scheme, host, port, path
 
 
-def request(method: str, url: str, headers: list[tuple[str, str]] = None, data: bytes = None,
+def request(method: str, url: str, headers: list = None, data: bytes = None,
             http2_prior_knowledge=False,
             normalize=True,
             validate=True,
@@ -246,7 +246,7 @@ def request(method: str, url: str, headers: list[tuple[str, str]] = None, data:
     return resp_seq[1]
 
 
-def get(url: str, headers: list[tuple[str, str]] = None, data: bytes = None,
+def get(url: str, headers: list = None, data: bytes = None,
         http2_prior_knowledge=False,
         normalize=True,
         validate=True,
@@ -255,7 +255,7 @@ def get(url: str, headers: list[tuple[str, str]] = None, data: bytes = None,
                    normalize=normalize, validate=validate, timeout=timeout)
 
 
-def post(url: str, headers: list[tuple[str, str]] = None, data: bytes = None,
+def post(url: str, headers: list = None, data: bytes = None,
          http2_prior_knowledge=False,
          normalize=True,
          validate=True,
@@ -265,9 +265,9 @@ def post(url: str, headers: list[tuple[str, str]] = None, data: bytes = None,
 
 
 class Session:
-    def __del__(self):
-        if self.__connection.fileno() != -1:
-            self.close()
+    # def __del__(self):
+    #     if self.__connection.fileno() != -1:
+    #         self.close()
 
     def __init__(self, host: str, port: int, config: h2.connection.H2Configuration = h2.connection.H2Configuration(),
                  http2_prior_knowledge: bool = False,
@@ -300,7 +300,7 @@ class Session:
         # close the socket
         self.__tls_connection.close()
 
-    def request(self, method: str, url: str, headers: list[tuple[str, str]] = None, data: bytes = None,
+    def request(self, method: str, url: str, headers: list = None, data: bytes = None,
                 timeout: int = 15) -> HttpStruct:
         self.__stream_id += 2
         if not self.__tls_connection.session:
@@ -338,6 +338,7 @@ class Session:
             # print("after receive data before")
 
             if not recv_data:
+                self.close()
                 raise RuntimeError(f"{url} <StreamId: {self.__stream_id}>: no data receive")
                 # break
 
@@ -369,7 +370,8 @@ class Session:
                     pass
 
                 elif isinstance(event, StreamReset):
-
+                    # print(headers, data)
+                    self.close()
                     raise RuntimeError(f"{url} <StreamId: {event.stream_id}>: StreamReset, {str(event.error_code)}")
                     # self.close()
                     # return resp_seq[event.stream_id]
@@ -382,8 +384,8 @@ class Session:
         # print(resp_body)
         return resp_seq[self.__stream_id]
 
-    def get(self, url, data: bytes = None, headers: list[tuple[str, str]] = None, timeout: int = 10):
+    def get(self, url, data: bytes = None, headers: list = None, timeout: int = 10):
         return self.request("GET", url, data=data, headers=headers, timeout=timeout)
 
-    def post(self, url, data: bytes = None, headers: list[tuple[str, str]] = None, timeout: int = 10):
+    def post(self, url, data: bytes = None, headers: list = None, timeout: int = 10):
         return self.request("POST", url, data=data, headers=headers, timeout=timeout)
